==> speech-analytic-testing_1.9.0_database.tar.gz: database/mssql/procedures/SaveHistoricStudyData.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[SaveHistoricStudyData] (
	@VCC VARCHAR(50) =        NULL,
	@TemplateId VARCHAR(50) = NULL
) AS
BEGIN
	SET NOCOUNT ON
	  
	  IF(NOT EXISTS(SELECT 
				T.[Name]
			FROM [dbo].[HistoricTemplate] T (NOLOCK)
			WHERE T.[Name]=@TemplateId AND T.[VCC]=@VCC))
	  BEGIN
			INSERT INTO [dbo].[HistoricTemplate] 
			SELECT 
				T.[VCC],
				T.[Name],
				T.[Type],
				T.[Description],
				T.[Template],
				T.[Category]
			FROM [dbo].[Template] T (NOLOCK)
			WHERE T.[Name]=@TemplateId AND T.[VCC]=@VCC
	  END

	  IF(NOT EXISTS(SELECT
				TT.[ID]
			FROM [dbo].[HistoricTemplateTheme] TT (NOLOCK)
			WHERE TT.[TemplateId] = @TemplateId AND TT.[VCC]=@VCC))
	  BEGIN
	  INSERT INTO [dbo].[HistoricTemplateTheme]
			SELECT
				TT.[VCC],
				TT.[TemplateId],
				TT.[ID],
				TT.[Order],
				TT.[Description],
				TT.[Category1],
				TT.[Category2],
				TT.[AnalysisType],
				TT.[IsNegative]
			FROM [dbo].[TemplateTheme] TT (NOLOCK)
			WHERE TT.[TemplateId] = @TemplateId AND TT.[VCC]=@VCC
	  END


	  IF(NOT EXISTS(SELECT 
				TTI.[ID]
			FROM [dbo].[HistoricTemplateThemeItem] TTI (NOLOCK)
			WHERE TTI.[TemplateId] = @TemplateId AND TTI.[VCC]=@VCC))
	  BEGIN
			INSERT INTO [dbo].[HistoricTemplateThemeItem]
			SELECT 
				TTI.[VCC],
				TTI.[TemplateId],
				TTI.[TemplateThemeId],
				TTI.[ID],
				TTI.[AcceptancePercentage]
			FROM [dbo].[TemplateThemeItem] TTI (NOLOCK)
			WHERE TTI.[TemplateId] = @TemplateId AND TTI.[VCC]=@VCC
	  END

	  IF(NOT EXISTS(SELECT 
			TTIE.[EntityId]
		FROM [dbo].[HistoricTemplateThemeItemEntity] TTIE (NOLOCK)
		WHERE TTIE.[TemplateId] = @TemplateId AND TTIE.[VCC] = @VCC))
	  BEGIN
		INSERT INTO [dbo].[HistoricTemplateThemeItemEntity]
		SELECT 
			TTIE.[VCC],
			TTIE.[TemplateId],
			TTIE.[TemplateThemeId],
			TTIE.[TemplateThemeItemId],
			TTIE.[EntityId],
			TTIE.[EntityName],
			TTIE.[AcceptancePercentage],
			TTIE.[Order]
		FROM [dbo].[TemplateThemeItemEntity] TTIE (NOLOCK)
		WHERE TTIE.[TemplateId] = @TemplateId AND TTIE.[VCC] = @VCC
	  END

	  IF(NOT EXISTS(SELECT
				GTQ.[ID]
			FROM [dbo].[HistoricGenericTemplateQuery] GTQ (NOLOCK)
            WHERE GTQ.[TemplateId] = @TemplateId AND GTQ.[VCC] = @VCC))
	  BEGIN
	  INSERT INTO [dbo].[HistoricGenericTemplateQuery]
			SELECT
				GTQ.[VCC],
				GTQ.[TemplateId],
				GTQ.[ID],
				GTQ.[Query]
			FROM [dbo].[GenericTemplateQuery] GTQ (NOLOCK)
            WHERE GTQ.[TemplateId] = @TemplateId AND GTQ.[VCC] = @VCC
	  END
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_2.4.1_database.tar.gz: database/mssql/procedures/SaveHistoricStudyData.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[SaveHistoricStudyData] (
	@VCC VARCHAR(50) =        NULL,
	@StudyId    VARCHAR(50) = NULL,
	@TemplateId VARCHAR(50) = NULL
) AS
BEGIN
	SET NOCOUNT ON
	  

			INSERT INTO [dbo].[HistoricTemplate] 
			SELECT 
				T.[VCC],
				T.[Name],
				T.[Type],
				T.[Description],
				T.[Template],
				T.[Category],
				@StudyId
			FROM [dbo].[Template] T (NOLOCK)
			WHERE T.[Name]=@TemplateId AND T.[VCC]=@VCC



	  INSERT INTO [dbo].[HistoricTemplateTheme]
			SELECT
				TT.[VCC],
				TT.[TemplateId],
				TT.[ID],
				TT.[Order],
				TT.[Description],
				TT.[Category1],
				TT.[Category2],
				TT.[AnalysisType],
				TT.[IsNegative],
				@StudyId
			FROM [dbo].[TemplateTheme] TT (NOLOCK)
			WHERE TT.[TemplateId] = @TemplateId AND TT.[VCC]=@VCC




			INSERT INTO [dbo].[HistoricTemplateThemeItem]
			SELECT 
				TTI.[VCC],
				TTI.[TemplateId],
				TTI.[TemplateThemeId],
				TTI.[ID],
				TTI.[AcceptancePercentage],
				@StudyId
			FROM [dbo].[TemplateThemeItem] TTI (NOLOCK)
			WHERE TTI.[TemplateId] = @TemplateId AND TTI.[VCC]=@VCC


		INSERT INTO [dbo].[HistoricTemplateThemeItemEntity]
		SELECT 
			TTIE.[VCC],
			TTIE.[TemplateId],
			TTIE.[TemplateThemeId],
			TTIE.[TemplateThemeItemId],
			TTIE.[EntityId],
			TTIE.[EntityName],
			TTIE.[AcceptancePercentage],
			TTIE.[Order],
			@StudyId
		FROM [dbo].[TemplateThemeItemEntity] TTIE (NOLOCK)
		WHERE TTIE.[TemplateId] = @TemplateId AND TTIE.[VCC] = @VCC


	  INSERT INTO [dbo].[HistoricGenericTemplateQuery]
			SELECT
				GTQ.[VCC],
				GTQ.[TemplateId],
				GTQ.[ID],
				GTQ.[Query],
				@StudyId
			FROM [dbo].[GenericTemplateQuery] GTQ (NOLOCK)
            WHERE GTQ.[TemplateId] = @TemplateId AND GTQ.[VCC] = @VCC

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
